/* Project Name:
     TouchPanel (Demo for working with TouchPanel Controller)
 * Copyright:
     (c) mikroElektronika, 2011.
 * Revision History:
     20110110:
       - Initial release (TL)
     20110613:
       - Adapted GLCD and touch panel declarations for 18F8722 (ZR)
 * Description:
     This code in intended to work with TouchPanel and SmartGLCD.
* Test configuration:
     MCU:             PIC18F8722
                      http://ww1.microchip.com/downloads/en/DeviceDoc/39646c.pdf
     Dev.Tool:        SmartGLCD
                      http://www.mikroe.com/eng/products/view/443/smartglcd-240x128-board/
                      PICFlash with mikroICD support
                      http://www.mikroe.com/eng/products/view/18/picflash-with-mikroicd-support/
     Oscillator:      HS-PLL 4x, 40.0000 MHz
     Ext. Modules:    none.
     SW:              mikroC PRO for PIC
                      http://www.mikroe.com/en/compilers/mikroc/pro/pic/
*/

#include        "__T6963C.h"

// T6963C module connections
char T6963C_dataPort at PORTH;
sbit T6963C_ctrlwr at RJ2_bit;
sbit T6963C_ctrlrd at RJ1_bit;
sbit T6963C_ctrlcd at RJ0_bit;
sbit T6963C_ctrlrst at RJ4_bit;
sbit T6963C_ctrlwr_Direction at TRISJ2_bit;
sbit T6963C_ctrlrd_Direction at TRISJ1_bit;
sbit T6963C_ctrlcd_Direction at TRISJ0_bit;
sbit T6963C_ctrlrst_Direction at TRISJ4_bit;
sbit T6963C_ctrlce at RJ3_bit;
sbit T6963C_ctrlfs at RJ6_bit;
sbit T6963C_ctrlmd at RJ5_bit;
sbit T6963C_ctrlce_Direction at TRISJ3_bit;
sbit T6963C_ctrlfs_Direction at TRISJ6_bit;
sbit T6963C_ctrlmd_Direction at TRISJ5_bit;

sbit BacklightRed_Direction  at TRISC2_bit;
sbit BacklightGreen_Direction at TRISC1_bit;
sbit BacklightBlue_Direction  at TRISG0_bit;
sbit BacklightRed   at RC2_bit;
sbit BacklightGreen at RC1_bit;
sbit BacklightBlue  at RG0_bit;
// End T6963C module connections


// Touch Panel module connections
sbit DriveA at LATG3_bit;
sbit DriveB at LATG4_bit;
sbit DriveA_Direction at TRISG3_bit;
sbit DriveB_Direction at TRISG4_bit;
// End Touch Panel module connections

char write_erase, color, test[10];
unsigned int x_coord, y_coord, x_coord_old, y_coord_old, x_coord_diff, y_coord_diff;
long         x_coord240, y_coord128;                         // scaled x-y position
int          i, cal_x_min, cal_y_min, cal_x_max, cal_y_max;  // calibration constants
char PenDown;
void *PressedObject;
char write_msg[] = "WRITE";                     // GLCD menu messages
char clear_msg[] = "CLEAR";
char erase_msg[] = "ERASE";
const unsigned int ADC_THRESHOLD = 500;         // Threshold value for press detecting

// returns 1 if TouchPanel is pressed, 0 otherwise
char PressDetect() {
  unsigned adc_rd;
  char result;

  // PRESS detecting
  DRIVEA = 0; //(LEFT drive off, RIGHT drive off, TOP drive on)
  DRIVEB = 0; // (BOTTOM drive off)
  Delay_us(3500);

  adc_rd = ADC_read(1);                                   // Read RA1 (READ-Y)

  result = (adc_rd > ADC_THRESHOLD);                      // if logical one is detectet

  return result;
}

unsigned int GetX() {
  unsigned int result;
  // Reading X
  DRIVEA = 1; //(LEFT drive on, RIGHT drive on, TOP drive off)
  DRIVEB = 0; //(BOTTOM drive off)

  Delay_ms(5);
  result = ADC_read(0); // reading X value from RA0 (BOTTOM)
  return result;
}

unsigned int GetY() {
  unsigned int result;
  // Reading Y
  DRIVEA = 0; // (LEFT drive off, RIGHT drive off, TOP drive on)
  DRIVEB = 1; // (BOTTOM drive on)

  Delay_ms(5);
  result = ADC_read(1); // reading Y value from RA1 (from LEFT)
  return result;
}

void Calibrate() {

  T6963C_box(0,126,1,127, T6963C_WHITE);
  T6963C_write_text("TOUCH BOTTOM LEFT", 6, 6, 1);
  while (!PressDetect());

  // Get calibration constants (reading and compensating TouchPanel nonlinearity)
  cal_x_min = GetX() - 3;
  cal_y_min = GetY() - 3;
  Delay_ms(700);

  T6963C_panelFill(0);
  T6963C_box(238, 1, 240, 0,T6963C_WHITE);
  T6963C_write_text("TOUCH UPPER RIGHT", 6, 6, 1);
  while (!PressDetect());

  // Get calibration constants (reading and compensating TouchPanel nonlinearity)
  cal_x_max = GetX() + 3;
  cal_y_max = GetY() + 3;
  Delay_ms(1500);
}

void main() {
  ADCON1 = 0x0D;
  ADC_Init();
  T6963C_ctrlce_Direction = 0;
  T6963C_ctrlce = 0;            // Enable T6963C
  T6963C_ctrlmd_Direction = 0;
  T6963C_ctrlmd = 0;            // Column number select
  T6963C_ctrlfs_Direction = 0;
  T6963C_ctrlfs = 0;            // Wide Font

  BacklightRed_Direction   = 0; // Set backlight signals as outputs
  BacklightGreen_Direction = 0;
  BacklightBlue_Direction  = 0;
  BacklightRed   = 0;           // Turn on Red component of back light
  BacklightGreen = 0;           // Turn on Green component of back light
  BacklightBlue  = 0;           // Turn on Blue component of back light

  // Initialize T6963C
  T6963C_init(240, 128, 8);
  T6963C_graphics(1);
  T6963C_text(1);
  T6963C_cursor(0);

  TP_Init(240, 128, 0, 1);      // Initialize touch panel
  TP_Set_ADC_Threshold(500);    // Set touch panel ADC threshold

  PenDown = 0;
  PressedObject = 0;

  T6963C_graphics(1);
  T6963C_text(1);

  T6963C_panelFill(0);
  T6963C_write_text("CALIBRATION", 8, 6, 1);
  Delay_ms(3000);

  T6963C_panelFill(0);
  Calibrate();
  T6963C_panelFill(0);

  T6963C_write_text("WRITE ON SCREEN", 7, 6, 1) ;
  Delay_ms(1500);
  T6963C_panelFill(0);

  //Draw menus:
  T6963C_box(0,0,42,7,T6963C_WHITE);
  T6963C_write_text(clear_msg,0,0,0);
  T6963C_box(200,0,240,7,T6963C_WHITE);
  T6963C_write_text(erase_msg,25,0,0);
  T6963C_box(57,0,65,7,T6963C_WHITE);
  T6963C_write_char('R',7,0,0);
  T6963C_box(73,0,81,7,T6963C_WHITE);
  T6963C_write_char('G',9,0,0);
  T6963C_box(89,0,97,7,T6963C_WHITE);
  T6963C_write_char('B',11,0,0);
  T6963C_box(105,0,145,7,T6963C_WHITE);
  T6963C_write_text("Light",13,0,0);

  write_erase = 1;
  x_coord_old = 0;
  y_coord_old = 0;

  while (1) {

    if (PressDetect()) {
      // After a PRESS is detected read X-Y and convert it to 240x128 space
      x_coord = GetX() - cal_x_min;
      y_coord = GetY() - cal_y_min;

      // When lifting pen from the touchpanel surface GetX and GetY readings
      // (after correct PressDetect reading) may be incorrect
      x_coord_diff = abs(x_coord - x_coord_old);           // Compare with old values
      y_coord_diff = abs(y_coord - y_coord_old);
      x_coord_old = x_coord;                               // Save old values
      y_coord_old = y_coord;

      if ( (x_coord_diff>50) || (y_coord_diff>50) )        // If difference is too big then ignore the reading
        continue;

      x_coord240 = (x_coord * 240l) / (cal_x_max - cal_x_min);
      y_coord128 = (128 -(y_coord *128l) / (cal_y_max - cal_y_min));

      if ((x_coord240 < 0) || (x_coord240 > 239))
         continue;
      if ((y_coord128 < 0) || (y_coord128 > 127))
         continue;


      // If clear is pressed
      if ((x_coord240 < 32) && (y_coord128 < 8)) {

         T6963C_panelFill(0);

         // Draw menus:
         T6963C_box(0,0,42,7,T6963C_WHITE);
         T6963C_write_text(clear_msg,0,0,0);
         T6963C_box(200,0,240,7,T6963C_WHITE);
         if (write_erase)
           T6963C_write_text(erase_msg,25,0,0);
         else
           T6963C_write_text(write_msg,25,0,0);

         T6963C_box(57,0,65,7,T6963C_WHITE);
         T6963C_write_char('R',7,0,0);
         T6963C_box(73,0,81,7,T6963C_WHITE);
         T6963C_write_char('G',9,0,0);
         T6963C_box(89,0,97,7,T6963C_WHITE);
         T6963C_write_char('B',11,0,0);
         T6963C_box(105,0,145,7,T6963C_WHITE);
         T6963C_write_text("Light",13,0,0);
       }

      // If write/erase is pressed:
      if ((x_coord240 > 201) && (y_coord128 < 8)) {
         if (write_erase) {
           write_erase = 0;
           T6963C_write_text(write_msg,25,0,0);
           Delay_ms(200);
           }
         else {
           write_erase = 1;
           T6963C_write_text(erase_msg,25,0,0);
           Delay_ms(200);
           }
         }

      // If R button is pressed:
      if ((x_coord240 >= 57) && (x_coord240 <= 65) && (y_coord128 <= 7)) {
        PORTC.F2 = !PORTC.F2;   // Red
        Delay_ms(100);
      }

      // If G button is pressed:
      if ((x_coord240 >= 73) && (x_coord240 <= 81) && (y_coord128 <= 7)) {
        PORTC.F1 = !PORTC.F1;   // Green
        Delay_ms(100);
      }

      // If B button is pressed:
      if ((x_coord240 >= 89) && (x_coord240 <= 97) && (y_coord128 <= 7)) {
        PORTG.F0 = !PORTG.F0;   // Blue
        Delay_ms(100);
      }
      // If backlight button is pressed:
      if ((x_coord240 >= 105) && (x_coord240 <= 146) && (y_coord128 <= 7)) {
        PORTC.F2 = !PORTC.F2;   // Red
        PORTC.F1 = !PORTC.F1;   // Green
        PORTG.F0 = !PORTG.F0;   // Blue
        Delay_ms(100);
      }

      // Draw on the screen
      if (y_coord128 > 8)
      {
        if (write_erase) T6963C_dot(x_coord240, y_coord128, T6963C_WHITE);
        else T6963C_dot(x_coord240, y_coord128, T6963C_BLACK);
      }

    }
  }
}